"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.destination = void 0;
const tslib_1 = require("tslib");
const shim_1 = require("@segment/browser-destination-runtime/shim");
const trackCustomBehavioralEvent_1 = tslib_1.__importDefault(require("./trackCustomBehavioralEvent"));
const trackPageView_1 = tslib_1.__importDefault(require("./trackPageView"));
const upsertContact_1 = tslib_1.__importDefault(require("./upsertContact"));
const actions_core_1 = require("@segment/actions-core");
exports.destination = {
    name: 'Hubspot Web (Actions)',
    slug: 'actions-hubspot-web',
    mode: 'device',
    presets: [
        {
            name: 'Track Custom Behavioral Event',
            subscribe: 'type = "track"',
            partnerAction: 'trackCustomBehavioralEvent',
            mapping: actions_core_1.defaultValues(trackCustomBehavioralEvent_1.default.fields),
            type: 'automatic'
        },
        {
            name: 'Upsert Contact',
            subscribe: 'type = "identify"',
            partnerAction: 'upsertContact',
            mapping: actions_core_1.defaultValues(upsertContact_1.default.fields),
            type: 'automatic'
        },
        {
            name: 'Track Page View',
            subscribe: 'type = "page"',
            partnerAction: 'trackPageView',
            mapping: actions_core_1.defaultValues(trackPageView_1.default.fields),
            type: 'automatic'
        }
    ],
    settings: {
        portalId: {
            description: 'The Hub ID of your HubSpot account.',
            label: 'Hub ID',
            type: 'string',
            required: true
        },
        enableEuropeanDataCenter: {
            description: 'Enable this option if you would like Segment to load the HubSpot SDK for EU data residency.',
            label: 'Enable the European Data Center SDK.',
            type: 'boolean',
            required: false
        },
        flushIdentifyImmediately: {
            description: 'Enable this option to fire a `trackPageView` HubSpot event immediately after each Segment `identify` call to flush the data to HubSpot immediately.',
            label: 'Flush Identify Calls Immediately',
            type: 'boolean',
            required: false
        },
        formatCustomBehavioralEventNames: {
            description: 'Format the event names for custom behavioral event automatically to standard HubSpot format (`pe<HubID>_event_name`).',
            label: 'Format Custom Behavioral Event Names',
            type: 'boolean',
            required: false,
            default: true
        },
        loadFormsSDK: {
            description: 'Enable this option if you would like Segment to automatically load the HubSpot Forms SDK onto your site.',
            label: 'Load Forms SDK',
            type: 'boolean',
            required: false,
            default: false
        }
    },
    initialize: async ({ settings }, deps) => {
        const scriptPath = settings.enableEuropeanDataCenter
            ? `https://js-eu1.hs-scripts.com/${settings.portalId}.js`
            : `https://js.hs-scripts.com/${settings.portalId}.js`;
        const formsScriptPath = settings.enableEuropeanDataCenter
            ? 'https://js-eu1.hsforms.net/forms/v2.js'
            : 'https://js.hsforms.net/forms/v2.js';
        await deps.loadScript(scriptPath);
        if (settings.loadFormsSDK) {
            await deps.loadScript(formsScriptPath);
        }
        await deps.resolveWhen(() => !!(window._hsq && window._hsq.push !== Array.prototype.push) &&
            (!settings.loadFormsSDK || !!(window.hbspt && window.hbspt.forms)), 100);
        return window._hsq;
    },
    actions: {
        trackCustomBehavioralEvent: trackCustomBehavioralEvent_1.default,
        trackPageView: trackPageView_1.default,
        upsertContact: upsertContact_1.default
    }
};
exports.default = shim_1.browserDestination(exports.destination);
//# sourceMappingURL=index.js.map